Run model and check Costs against an expected value
Source:R/check_model_helpers.R
check_model_costs.RdRun model and check Costs against an expected value
Arguments
- expected_costs
The exact expected Cost value.
- ...
Arguments passed to
run_model().- label
A label for the test, passed to
expect_equal().
Examples
data(test_data)
check_model_costs(0, data = test_data, c_healthy = 0, c_sick = 0, c_intervention = 0, c_death = 0)