Run model and check Life Expectancy against an expected value
Source:R/check_model_helpers.R
check_model_le.RdRun model and check Life Expectancy against an expected value
Arguments
- expected_le
The exact expected LE value.
- ...
Arguments passed to
run_model().- label
A label for the test, passed to
expect_equal().
Examples
data(test_data)
check_model_le(1, data = test_data, p_healthy_death = 1, p_sick_death = 1)