Skip to contents

Getter for state costs

Usage

get_state_costs(input, arm = NULL)

Arguments

input

A list of model parameters.

arm

Optional treatment arm name (character) or index.

Value

A vector of state costs for the specified arm, or the full cost matrix if arm is NULL.

Examples

data(test_data)
get_state_costs(test_data, "without_drug")
#> Asymptomatic_disease  Progressive_disease                 Dead 
#>                  500                 3000                    0